==> Products.CMFPlomino-1.17.1.zip: Products.CMFPlomino-1.17.1/Products/CMFPlomino/browser/javascript/plomino.codemirror.js <==
$(document).ready(function() {
	plomino_types = ['plominoaction',
	                 'plominoagent',
	                 'plominocache',
	                 'plominocolumn',
	                 'plominohidewhen',
	                 'plominofield',
	                 'plominoview'];
	$(plomino_types).each(function(index, type) {
		$("#"+type+"-base-edit textarea").each(function() {
			this.onCodeMirrorSave = function() { 
				$("#"+type+"-base-edit").submit();
			};
			$(this).addClass('codemirror-python')
			$(this).attr('data-codemirror-mode', "python");
		});
	});
	
	// enable on all PlominoField settings page
	// TODO: SAVE
	$(".portaltype-plominofield #content-core textarea").each(function() {
		this.onCodeMirrorSave = function() {
			$("input[name='form.actions.apply']").click();
		};
		$(this).addClass('codemirror-python');
		$(this).attr('data-codemirror-mode', "python");
	});

	// plominoform textareas must be processed more precisely
	plomino_form_areas = ['DocumentTitle',
	                      'DocumentId',
	                      'SearchFormula',
	                      'onCreateDocument',
	                      'onOpenDocument',
	                      'onSaveDocument',
	                      'onDeleteDocument',
	                      'onSearch',
	                      'beforeCreateDocument',
	                      'beforeSaveDocument'
	                      ]
	$(plomino_form_areas).each(function(index, area) {
		$("#plominoform-base-edit #"+area).each(function() {
			this.onCodeMirrorSave = function() { 
				$("#plominoform-base-edit").submit();
			};
			$(this).addClass('codemirror-python');
			$(this).attr('data-codemirror-mode', "python");
		});
	});
});

==> Products.CMFPlomino-1.19.6.zip: Products.CMFPlomino-1.19.6/Products/CMFPlomino/browser/javascript/plomino.codemirror.js <==
$(document).ready(function() {
	plomino_types = ['plominoaction',
	                 'plominoagent',
	                 'plominocache',
	                 'plominocolumn',
	                 'plominohidewhen',
	                 'plominofield',
	                 'plominoview'];
	$(plomino_types).each(function(index, type) {
		$("#"+type+"-base-edit textarea").each(function() {
			// disable textarea #Formula for user role designer
			if($('.userrole-plominodesigner').length > 0){
				$(this).prop('disabled', true);
			} else {
				this.onCodeMirrorSave = function() {
					$("#"+type+"-base-edit").submit();
				};
				$(this).addClass('codemirror-python');
				$(this).attr('data-codemirror-mode', "python");
			}
		});
	});

	// enable on all PlominoField settings page
	// TODO: SAVE
	$(".portaltype-plominofield #content-core textarea").each(function() {
		this.onCodeMirrorSave = function() {
			$("input[name='form.actions.apply']").click();
		};
		$(this).addClass('codemirror-python');
		$(this).attr('data-codemirror-mode', "python");
	});

	// plominoform textareas must be processed more precisely
	plomino_form_areas = ['DocumentTitle',
	                      'DocumentId',
	                      'SearchFormula',
	                      'onCreateDocument',
	                      'onOpenDocument',
	                      'onSaveDocument',
	                      'onDeleteDocument',
	                      'onSearch',
	                      'beforeCreateDocument',
	                      'beforeSaveDocument'
	                      ]
	$(plomino_form_areas).each(function(index, area) {
		$("#plominoform-base-edit #"+area).each(function() {
			// disable textarea #Formula for user role designer
			if($('.userrole-plominodesigner').length > 0){
				$(this).prop('disabled', true);
			} else {
				this.onCodeMirrorSave = function() {
					$("#plominoform-base-edit").submit();
				};
				$(this).addClass('codemirror-python');
				$(this).attr('data-codemirror-mode', "python");
			}
		});
	});
});
